Complete Reference
==================

The contents of the submodules *baseline* and *peak* are imported to 
*peaktuils*, and there is no need to import them directly.

An exception is the *plot* submodule that must be explicitly imported due to its *matplotlib*
dependency.

peakutils.baseline
------------------

.. automodule:: peakutils.baseline
    :members:
    :special-members:

peakutils.peak
--------------
    
.. automodule:: peakutils.peak
    :members:
    :special-members:
    
peakutils.prepare
-----------------
    
.. automodule:: peakutils.prepare
    :members:
    :special-members:
    
peakutils.plot
--------------
    
.. automodule:: peakutils.plot
    :members:
    :special-members:
